#include "tao/Adapter_Factory.h"

// ****************************************************************

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_Adapter_Factory::~TAO_Adapter_Factory ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
